@@ -118,7 +118,7 @@ class testcase_locatecards(unittest.TestCase):
 
 def suite():
     suite1 = unittest.makeSuite(testcase_locatecards)
-    return unittest.TestSuite((suite1))
+    return unittest.TestSuite(suite1)
 
 
 if __name__ == '__main__':
